import PySimpleGUI as sg

sg.theme('DarkAmber')  # Add a touch of color
# All the stuff inside your window.
layout = [[sg.Text('Some text on Row 1')],
          [sg.Text('Enter something on Row 2'), sg.InputText()],
          [sg.Button('Ok'), sg.Button('Cancel')]]

# Create the Window
window = sg.Window('Window Title', layout)
# Event Loop to process "events" and get the "values" of the inputs
while True:
    event, values = window.read()
    if event == sg.WIN_CLOSED or event == 'Cancel':  # if user closes window or clicks cancel
        break
    print('You entered ', values[0])

window.close()



# !/usr/bin/env python
# -*- coding:utf-8 -*-
import PySimpleGUI as sg

sg.theme("DarkAmber")

layout = [
    [sg.Text("unput file name")],
    [sg.Text("filename"), sg.InputText()],
    [sg.Button("enter"), sg.Button("cancel")],
]

windows = sg.Window("print file name", layout)


def activate():
    while True:
        event, value = windows.read()
        if event == sg.WINDOW_CLOSED or event == "cancel":
            break
        print(f"input content:{value[0]}")
    windows.close()


if __name__ == '__main__':
    activate()



from setuptools import setup, find_packages

setup(
    name="wpgui",
    version="0.0.3",
    keywords=["pip", "testpypi"],
    description="test pip module, start a simple gui",
    long_description="test how to define pip module and upload to pypi, activate a simple gui",
    license="MIT",
    url="https://beyond.3dnest.cn/",  # your module home page, such as
    author="wp",  # your name
    author_email="wupengyu@3dnest.com",  # your email
    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=["PySimpleGUI", ]
)
